@@ -88,11 +88,14 @@ class TestEsiFetch(NoSocketsTestCase):
         )
         self.assertEqual(kwargs, {"category_id": 65, "token": "my_access_token"})
 
-    @patch(MODULE_PATH + "._esi_client")
-    def test_can_fetch_object_from_esi_wo_args(self, mock_esi_client):
-        mock_esi_client.side_effect = esi_mock_client
+    # @patch(MODULE_PATH + "._esi_client")
+    def test_can_fetch_object_from_esi_wo_args(self):
+        # mock_esi_client.side_effect = esi_mock_client
+        mock_client = esi_mock_client()
         solar_systems = esi_fetch(
-            esi_path="Universe.get_universe_systems", logger_tag="dummy"
+            esi_path="Universe.get_universe_systems",
+            logger_tag="dummy",
+            esi_client=mock_client,
         )
         expected = [30002506, 31000005, 30002537, 30000474, 30000476]
         self.assertSetEqual(set(solar_systems), set(expected))
@@ -140,6 +143,8 @@ class TestEsiFetch(NoSocketsTestCase):
     @patch(MODULE_PATH + ".ESI_RETRY_SLEEP_SECS", 0)
     @patch(MODULE_PATH + "._esi_client")
     def test_can_retry_on_exceptions(self, mock_esi_client):
+        MyException = RuntimeError
+
         def my_side_effect(**kwargs):
             """special mock client for testing retry ability"""
             nonlocal retry_counter, max_retries
@@ -147,7 +152,8 @@ class TestEsiFetch(NoSocketsTestCase):
             if retry_counter < max_retries:
                 retry_counter += 1
                 raise MyException(
-                    response=Mock(), message="retry_counter=%d" % retry_counter
+                    response=Mock(**{"text": "test"}),
+                    message="retry_counter=%d" % retry_counter,
                 )
             else:
                 return esi_get_universe_categories_category_id(category_id=65).result()
@@ -235,6 +241,30 @@ class TestEsiFetch(NoSocketsTestCase):
         expected = {"Clone Bay", "Market Hub"}
         self.assertEqual(service_names, expected)
 
+    def test_can_fetch_multiple_pages_2(self):
+        """fetching pages from django-esi 2.0 API"""
+        mock_client = esi_mock_client(version=2.0)
+
+        structures = esi_fetch(
+            "Corporation.get_corporations_corporation_id_structures",
+            args={"corporation_id": 2001},
+            esi_client=mock_client,
+            has_pages=True,
+        )
+
+        # has all structures
+        structure_ids = {x["structure_id"] for x in structures}
+        expected = {1000000000001, 1000000000002, 1000000000003}
+        self.assertSetEqual(structure_ids, expected)
+
+        # has services
+        service_names = list()
+        for obj in structures:
+            if obj["structure_id"] == 1000000000001:
+                service_names = {x["name"] for x in obj["services"]}
+        expected = {"Clone Bay", "Market Hub"}
+        self.assertEqual(service_names, expected)
+
     def test_can_fetch_multiple_pages_and_languages(self):
         mock_client = esi_mock_client()
 
